fn source_suffix(source: ConfigValueSource) -> &'static strExpand description
Returns the visual suffix used when a value is overridden by the environment.
fn source_suffix(source: ConfigValueSource) -> &'static strReturns the visual suffix used when a value is overridden by the environment.